<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\Ger96500MonitoramentoFechamentoCupomService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Ger96500MonitoramentoFechamentoCupomController {

    protected $monitoramentoService;

    public function __construct(Ger96500MonitoramentoFechamentoCupomService $monitoramentoService) {
        $this->monitoramentoService = $monitoramentoService;
    }

    /*
     * Função para buscar os cupons por dia das filiais parametrizadas,
     * independentemente dos caixas envolvidos.
     */
    public function findCuponsFiliais(DTO\Request $request, DTO\Response $response) {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $params = array();
            foreach ($filters as $filter) {
                $params[$filter["columnName"]] = $filter["value"];
            }

            // Chama a função de aprovação, retornando quaisquer erros encontrados.
            $cuponsData = $this->monitoramentoService->getCuponsDistinctFiliais($params);
            $response->addDataset(new DataSet("reducaoz_monitoramento_cupons", $cuponsData));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para buscar todos os cupons por dia das filiais parametrizadas.
     */
    public function findCuponsCaixas(DTO\Request $request, DTO\Response $response) {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $params = array();
            foreach ($filters as $filter) {
                $params[$filter["columnName"]] = $filter["value"];
            }

            // Chama a função de aprovação, retornando quaisquer erros encontrados.
            $cuponsData = $this->monitoramentoService->getCuponsDistinctCaixas($params);

            $response->addDataset(new DataSet("reducaoz_monitoramento_cupons_caixa", $cuponsData));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    /*
     * Função para buscar os erros de pré-validação de um cupom pendente.
     */
    public function findErrosPreValidacao(DTO\Request $request, DTO\Response $response) {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $params = array();
            foreach ($filters as $filter) {
                $params[$filter["columnName"]] = $filter["value"];
            }

            // Chama a função de aprovação, retornando quaisquer erros encontrados.
            $errosPreValidacao = $this->monitoramentoService->getErrosPreValidacao($params);

            $response->addDataset(new DataSet("monitoramento_cupons_prevalidacao", $errosPreValidacao));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
}